@@ -1,37 +1,50 @@
+import importlib
 import subprocess
 import sys
+from types import ModuleType
 
+import pytest
 from typer.testing import CliRunner
 
-from docs_src.arguments.default import tutorial002 as mod
-
 runner = CliRunner()
-app = mod.app
 
 
-def test_help():
-    result = runner.invoke(app, ["--help"])
+@pytest.fixture(
+    name="mod",
+    params=[
+        pytest.param("tutorial002_py310"),
+        pytest.param("tutorial002_an_py310"),
+    ],
+)
+def get_mod(request: pytest.FixtureRequest) -> ModuleType:
+    module_name = f"docs_src.arguments.default.{request.param}"
+    mod = importlib.import_module(module_name)
+    return mod
+
+
+def test_help(mod: ModuleType):
+    result = runner.invoke(mod.app, ["--help"])
     assert result.exit_code == 0
     assert "[OPTIONS] [NAME]" in result.output
     assert "Arguments" in result.output
     assert "[default: (dynamic)]" in result.output
 
 
-def test_call_no_arg():
+def test_call_no_arg(mod: ModuleType):
     greetings = ["Hello Deadpool", "Hello Rick", "Hello Morty", "Hello Hiro"]
     for _i in range(3):
-        result = runner.invoke(app)
+        result = runner.invoke(mod.app)
         assert result.exit_code == 0
         assert any(greet in result.output for greet in greetings)
 
 
-def test_call_arg():
-    result = runner.invoke(app, ["Camila"])
+def test_call_arg(mod: ModuleType):
+    result = runner.invoke(mod.app, ["Camila"])
     assert result.exit_code == 0
     assert "Hello Camila" in result.output
 
 
-def test_script():
+def test_script(mod: ModuleType):
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
         capture_output=True,
