@@ -1,19 +1,29 @@
+import importlib
 import subprocess
 import sys
+from types import ModuleType
 
-import typer
+import pytest
 from typer.testing import CliRunner
 
-from docs_src.arguments.help import tutorial002 as mod
-
 runner = CliRunner()
 
-app = typer.Typer()
-app.command()(mod.main)
+
+@pytest.fixture(
+    name="mod",
+    params=[
+        pytest.param("tutorial002_py310"),
+        pytest.param("tutorial002_an_py310"),
+    ],
+)
+def get_mod(request: pytest.FixtureRequest) -> ModuleType:
+    module_name = f"docs_src.arguments.help.{request.param}"
+    mod = importlib.import_module(module_name)
+    return mod
 
 
-def test_help():
-    result = runner.invoke(app, ["--help"])
+def test_help(mod: ModuleType):
+    result = runner.invoke(mod.app, ["--help"])
     assert result.exit_code == 0
     assert "[OPTIONS] NAME" in result.output
     assert "Say hi to NAME very gently, like Dirk." in result.output
@@ -23,13 +33,13 @@ def test_help():
     assert "[required]" in result.output
 
 
-def test_call_arg():
-    result = runner.invoke(app, ["Camila"])
+def test_call_arg(mod: ModuleType):
+    result = runner.invoke(mod.app, ["Camila"])
     assert result.exit_code == 0
     assert "Hello Camila" in result.output
 
 
-def test_script():
+def test_script(mod: ModuleType):
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
         capture_output=True,
