@@ -12,8 +12,8 @@ runner = CliRunner()
 @pytest.fixture(
     name="mod",
     params=[
-        pytest.param("tutorial004_py39"),
-        pytest.param("tutorial004_an_py39"),
+        pytest.param("tutorial004_py310"),
+        pytest.param("tutorial004_an_py310"),
     ],
 )
 def get_mod(request: pytest.FixtureRequest) -> ModuleType:
@@ -28,7 +28,9 @@ def test_call(mod: ModuleType):
     assert "Hello Wade Wilson" in result.output
 
 
-def test_help(mod: ModuleType):
+def test_help(monkeypatch, mod: ModuleType):
+    # avoid default width of 80 for non-attached consoles during testing
+    monkeypatch.setenv("COLUMNS", "200")
     result = runner.invoke(mod.app, ["--help"])
     assert result.exit_code == 0
     assert "--fullname" in result.output
