@@ -7,18 +7,14 @@ import pytest
 import typer
 from typer.testing import CliRunner
 
-from ....utils import needs_py310
-
 runner = CliRunner()
 
 
 @pytest.fixture(
     name="mod",
     params=[
-        pytest.param("tutorial002_py39"),
-        pytest.param("tutorial002_py310", marks=needs_py310),
-        pytest.param("tutorial002_an_py39"),
-        pytest.param("tutorial002_an_py310", marks=needs_py310),
+        pytest.param("tutorial002_py310"),
+        pytest.param("tutorial002_an_py310"),
     ],
 )
 def get_mod(request: pytest.FixtureRequest) -> ModuleType:
